#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''Models of logical quantum problems.'''
from dataclasses import dataclass


@dataclass
class LogicalCircuit:
    '''Logical quantum circuit.'''
    name: str      # problem name
    qubits: int    # logical width: number of qubits
    tgates: int    # logical depth: number of T-gates


_qubits = [1e2, 1e3, 1e3, 1e3, 1e3, 1e4]
_tgates = [1e6, 1e6, 1e7, 1e8, 1e9, 1e10]
_names = ['hub8', 'hub20', 'p450.01', 'p450.1', 'p450', 'spf']

_circuits = [
    LogicalCircuit(
        name=n, qubits=q, tgates=t
    ) for n, q, t in zip(_names, _qubits, _tgates)
]


hub8 = _circuits[0]
hub20 = _circuits[1]
p450_01 = _circuits[2]
p450_1 = _circuits[3]
p450 = _circuits[4]
spf = _circuits[5]
